#!/usr/bin/python3
# -*- coding: utf-8 -*-
'''
	Copyright zmofun@163.com           All rights reserved!
	http://www.zmofun.com
	2000.1.14        TurboC++2.0

  zmofun@163.com
  2022.1.29    移植到PYTHON TKINTER版本之后，
  2022.2.1~2.3    移植到PyQt5版本
'''

from PyQt5.QtWidgets import QMainWindow, QDesktopWidget, QApplication, QHBoxLayout, QWidget
from PyQt5.QtCore import Qt, QBasicTimer
from PyQt5.QtGui import QPainter, QColor, QPen
import sys
from shape_PyQt5 import *
from game_box_PyQt5 import *


class Game(QMainWindow):
    def __init__(self):
        super().__init__()

        #keya = [87, 83, 65, 68]  # 上下左右w, s, a, d
        #keyb = [38, 40, 37, 39]  # 上下左右up, down, left, right

        keya = [Qt.Key_W, Qt.Key_S, Qt.Key_A, Qt.Key_D]  # 上下左右w, s, a, d
        keyb = [Qt.Key_Up, Qt.Key_Down, Qt.Key_Left,
                Qt.Key_Right]  # 上下左右up, down, left, right

        self.box = [GameBox(self), GameBox(self)]

        self.box[0].init(105, 50, 13, 16, 30, 40, keya)
        self.box[1].init(20, 50, 13, 16, 30, 260, keyb)

        self.resize(700, 520)
        self.center()
        self.setWindowTitle('Erase')

        self.main = QWidget(self)

        hboxlayout = QHBoxLayout(self.main)  # new
        hboxlayout.addWidget(self.box[0])
        hboxlayout.addWidget(self.box[1])

        self.main.setFocus()
        self.setCentralWidget(self.main)
        self.show()

        self.setFocusPolicy(Qt.StrongFocus)

        self.timer = QBasicTimer()
        self.timer.start(200, self)

    def center(self):
        '''centers the window on the screen'''
        screen = QDesktopWidget().screenGeometry()
        size = self.geometry()
        self.move((screen.width() - size.width()) / 2,
                  (screen.height() - size.height()) / 2)

    def paintEvent(self, event):
        canvas = QPainter(self)
        color = QColor(Qt.blue)
        canvas.setPen(QPen(Qt.blue, 1, Qt.SolidLine))
        canvas.fillRect(0, 0, 700, 520, color)

    def keyPressEvent(self, event):
        '''processes key press events'''
        key = event.key()
        if key == Qt.Key_Escape:
            exit(0)
        self.game_keypress(key)

    def timerEvent(self, event):
        '''handles timer event'''
        if event.timerId() == self.timer.timerId():
            self.box[0].play(1)
            self.box[1].play(1)
        else:
            super(Game, self).timerEvent(event)

    def game_keypress(self, key):
        if key in self.box[0].controlkey:
            self.box[0].play(key)
        if key in self.box[1].controlkey:
            self.box[1].play(key)


if __name__ == '__main__':
    app = QApplication([])
    game = Game()
    sys.exit(app.exec_())